// BuiltInFunctions.ts
export const builtInFunctions = {
    // Arithmetic Functions
    min: (...args) => Math.min(...args),
    max: (...args) => Math.max(...args),
    abs: (value) => Math.abs(value),
    ceil: (value) => Math.ceil(value),
    floor: (value) => Math.floor(value),
    round: (value) => Math.round(value),
    // String Functions
    contains: (str, substr) => str.includes(substr),
    endsWith: (str, substr) => str.endsWith(substr),
    indexOf: (str, substr) => str.indexOf(substr),
    length: (str) => str.length,
    lower: (str) => str.toLowerCase(),
    replace: (str, substr, newSubstr) => str.replace(substr, newSubstr),
    split: (str, separator) => str.split(separator),
    startsWith: (str, substr) => str.startsWith(substr),
    upper: (str) => str.toUpperCase(),
    // List Functions
    size: (value) => {
        if (typeof value === 'string' || Array.isArray(value)) {
            return value.length;
        }
        else if (value && typeof value === 'object') {
            return Object.keys(value).length;
        }
        else {
            throw new Error('size() function requires a string, array, or object');
        }
    },
    // Type Conversion Functions
    int: (value) => parseInt(value, 10),
    uint: (value) => Math.max(0, parseInt(value, 10)),
    double: (value) => parseFloat(value),
    string: (value) => String(value),
    bool: (value) => Boolean(value),
    // Null Handling Functions
    exists: (value) => value !== null && value !== undefined,
    existsOne: (list) => list.filter(item => item !== null && item !== undefined).length === 1,
    // Date/Time Functions
    matches: (value, regex) => {
        const re = new RegExp(regex);
        return re.test(value);
    },
    timestamp: (value) => {
        // Check if the input matches a date-only format (YYYY-MM-DD)
        const dateOnlyRegex = /^\d{4}-\d{2}-\d{2}$/;
        if (dateOnlyRegex.test(value)) {
            // Append time to date-only format and parse as ISO timestamp
            value = `${value}T00:00:00Z`;
        }
        const date = new Date(value);
        if (isNaN(date.getTime())) {
            throw new Error(`Invalid timestamp: ${value}`);
        }
        return date;
    },
    type: (value) => {
        if (value === null)
            return 'null';
        switch (typeof value) {
            case 'boolean':
                return 'bool';
            case 'number':
                return Number.isInteger(value) ? 'int' : 'float';
            case 'string':
                return 'string';
            case 'object':
                if (Array.isArray(value))
                    return 'list';
                else
                    return 'object';
            default:
                return typeof value;
        }
    },
    duration: (seconds) => `${seconds}s`,
    time: (year, month, day, hour, minute, second, millisecond) => {
        return new Date(Date.UTC(year, month - 1, day, hour, minute, second, millisecond)).toISOString();
    },
    date: (year, month, day) => {
        return new Date(Date.UTC(year, month - 1, day)).toISOString().split('T')[0];
    },
    getFullYear: (date) => date.getUTCFullYear(),
    getMonth: (date) => date.getUTCMonth(),
    getDate: (date) => date.getUTCDate(),
    getHours: (date) => date.getUTCHours(),
    getMinutes: (date) => date.getUTCMinutes(),
    getSeconds: (date) => date.getUTCSeconds(),
    compareDates: (date1, date2) => date1.getTime() - date2.getTime(),
};
