import { ATN, DFA, FailedPredicateException, Parser, RuleContext, ParserRuleContext, TerminalNode, Token, TokenStream } from 'antlr4';
import CELListener from "./CELListener.js";
import CELVisitor from "./CELVisitor.js";
export default class CELParser extends Parser {
    static readonly EQUALS = 1;
    static readonly NOT_EQUALS = 2;
    static readonly IN = 3;
    static readonly LESS = 4;
    static readonly LESS_EQUALS = 5;
    static readonly GREATER_EQUALS = 6;
    static readonly GREATER = 7;
    static readonly LOGICAL_AND = 8;
    static readonly LOGICAL_OR = 9;
    static readonly LBRACKET = 10;
    static readonly RPRACKET = 11;
    static readonly LBRACE = 12;
    static readonly RBRACE = 13;
    static readonly LPAREN = 14;
    static readonly RPAREN = 15;
    static readonly DOT = 16;
    static readonly COMMA = 17;
    static readonly MINUS = 18;
    static readonly EXCLAM = 19;
    static readonly QUESTIONMARK = 20;
    static readonly COLON = 21;
    static readonly PLUS = 22;
    static readonly STAR = 23;
    static readonly SLASH = 24;
    static readonly PERCENT = 25;
    static readonly TRUE = 26;
    static readonly FALSE = 27;
    static readonly NULL = 28;
    static readonly WHITESPACE = 29;
    static readonly COMMENT = 30;
    static readonly NUM_FLOAT = 31;
    static readonly NUM_INT = 32;
    static readonly NUM_UINT = 33;
    static readonly STRING = 34;
    static readonly BYTES = 35;
    static readonly IDENTIFIER = 36;
    static readonly EOF: number;
    static readonly RULE_start = 0;
    static readonly RULE_expr = 1;
    static readonly RULE_conditionalOr = 2;
    static readonly RULE_conditionalAnd = 3;
    static readonly RULE_relation = 4;
    static readonly RULE_calc = 5;
    static readonly RULE_unary = 6;
    static readonly RULE_member = 7;
    static readonly RULE_primary = 8;
    static readonly RULE_exprList = 9;
    static readonly RULE_fieldInitializerList = 10;
    static readonly RULE_mapInitializerList = 11;
    static readonly RULE_literal = 12;
    static readonly literalNames: (string | null)[];
    static readonly symbolicNames: (string | null)[];
    static readonly ruleNames: string[];
    get grammarFileName(): string;
    get literalNames(): (string | null)[];
    get symbolicNames(): (string | null)[];
    get ruleNames(): string[];
    get serializedATN(): number[];
    protected createFailedPredicateException(predicate?: string, message?: string): FailedPredicateException;
    constructor(input: TokenStream);
    start(): StartContext;
    expr(): ExprContext;
    conditionalOr(): ConditionalOrContext;
    conditionalAnd(): ConditionalAndContext;
    relation(): RelationContext;
    relation(_p: number): RelationContext;
    calc(): CalcContext;
    calc(_p: number): CalcContext;
    unary(): UnaryContext;
    member(): MemberContext;
    member(_p: number): MemberContext;
    primary(): PrimaryContext;
    exprList(): ExprListContext;
    fieldInitializerList(): FieldInitializerListContext;
    mapInitializerList(): MapInitializerListContext;
    literal(): LiteralContext;
    sempred(localctx: RuleContext, ruleIndex: number, predIndex: number): boolean;
    private relation_sempred;
    private calc_sempred;
    private member_sempred;
    static readonly _serializedATN: number[];
    private static __ATN;
    static get _ATN(): ATN;
    static DecisionsToDFA: DFA[];
}
export declare class StartContext extends ParserRuleContext {
    _e: ExprContext;
    constructor(parser?: CELParser, parent?: ParserRuleContext, invokingState?: number);
    EOF(): TerminalNode;
    expr(): ExprContext;
    get ruleIndex(): number;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class ExprContext extends ParserRuleContext {
    _e: ConditionalOrContext;
    _op: Token;
    _e1: ConditionalOrContext;
    _e2: ExprContext;
    constructor(parser?: CELParser, parent?: ParserRuleContext, invokingState?: number);
    conditionalOr_list(): ConditionalOrContext[];
    conditionalOr(i: number): ConditionalOrContext;
    COLON(): TerminalNode;
    QUESTIONMARK(): TerminalNode;
    expr(): ExprContext;
    get ruleIndex(): number;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class ConditionalOrContext extends ParserRuleContext {
    _e: ConditionalAndContext;
    _s9: Token;
    _ops: Token[];
    _conditionalAnd: ConditionalAndContext;
    _e1: ConditionalAndContext[];
    constructor(parser?: CELParser, parent?: ParserRuleContext, invokingState?: number);
    conditionalAnd_list(): ConditionalAndContext[];
    conditionalAnd(i: number): ConditionalAndContext;
    LOGICAL_OR_list(): TerminalNode[];
    LOGICAL_OR(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class ConditionalAndContext extends ParserRuleContext {
    _e: RelationContext;
    _s8: Token;
    _ops: Token[];
    _relation: RelationContext;
    _e1: RelationContext[];
    constructor(parser?: CELParser, parent?: ParserRuleContext, invokingState?: number);
    relation_list(): RelationContext[];
    relation(i: number): RelationContext;
    LOGICAL_AND_list(): TerminalNode[];
    LOGICAL_AND(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class RelationContext extends ParserRuleContext {
    constructor(parser?: CELParser, parent?: ParserRuleContext, invokingState?: number);
    get ruleIndex(): number;
    copyFrom(ctx: RelationContext): void;
}
export declare class RelationOpContext extends RelationContext {
    _op: Token;
    constructor(parser: CELParser, ctx: RelationContext);
    relation_list(): RelationContext[];
    relation(i: number): RelationContext;
    LESS(): TerminalNode;
    LESS_EQUALS(): TerminalNode;
    GREATER_EQUALS(): TerminalNode;
    GREATER(): TerminalNode;
    EQUALS(): TerminalNode;
    NOT_EQUALS(): TerminalNode;
    IN(): TerminalNode;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class RelationCalcContext extends RelationContext {
    constructor(parser: CELParser, ctx: RelationContext);
    calc(): CalcContext;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class CalcContext extends ParserRuleContext {
    constructor(parser?: CELParser, parent?: ParserRuleContext, invokingState?: number);
    get ruleIndex(): number;
    copyFrom(ctx: CalcContext): void;
}
export declare class CalcMulDivContext extends CalcContext {
    _op: Token;
    constructor(parser: CELParser, ctx: CalcContext);
    calc_list(): CalcContext[];
    calc(i: number): CalcContext;
    STAR(): TerminalNode;
    SLASH(): TerminalNode;
    PERCENT(): TerminalNode;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class CalcUnaryContext extends CalcContext {
    constructor(parser: CELParser, ctx: CalcContext);
    unary(): UnaryContext;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class CalcAddSubContext extends CalcContext {
    _op: Token;
    constructor(parser: CELParser, ctx: CalcContext);
    calc_list(): CalcContext[];
    calc(i: number): CalcContext;
    PLUS(): TerminalNode;
    MINUS(): TerminalNode;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class UnaryContext extends ParserRuleContext {
    constructor(parser?: CELParser, parent?: ParserRuleContext, invokingState?: number);
    get ruleIndex(): number;
    copyFrom(ctx: UnaryContext): void;
}
export declare class LogicalNotContext extends UnaryContext {
    _s19: Token;
    _ops: Token[];
    constructor(parser: CELParser, ctx: UnaryContext);
    member(): MemberContext;
    EXCLAM_list(): TerminalNode[];
    EXCLAM(i: number): TerminalNode;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class MemberExprContext extends UnaryContext {
    constructor(parser: CELParser, ctx: UnaryContext);
    member(): MemberContext;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class NegateContext extends UnaryContext {
    _s18: Token;
    _ops: Token[];
    constructor(parser: CELParser, ctx: UnaryContext);
    member(): MemberContext;
    MINUS_list(): TerminalNode[];
    MINUS(i: number): TerminalNode;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class MemberContext extends ParserRuleContext {
    constructor(parser?: CELParser, parent?: ParserRuleContext, invokingState?: number);
    get ruleIndex(): number;
    copyFrom(ctx: MemberContext): void;
}
export declare class SelectOrCallContext extends MemberContext {
    _op: Token;
    _id: Token;
    _open: Token;
    _args: ExprListContext;
    constructor(parser: CELParser, ctx: MemberContext);
    member(): MemberContext;
    DOT(): TerminalNode;
    IDENTIFIER(): TerminalNode;
    RPAREN(): TerminalNode;
    LPAREN(): TerminalNode;
    exprList(): ExprListContext;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class PrimaryExprContext extends MemberContext {
    constructor(parser: CELParser, ctx: MemberContext);
    primary(): PrimaryContext;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class IndexContext extends MemberContext {
    _op: Token;
    _index: ExprContext;
    constructor(parser: CELParser, ctx: MemberContext);
    member(): MemberContext;
    RPRACKET(): TerminalNode;
    LBRACKET(): TerminalNode;
    expr(): ExprContext;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class CreateMessageContext extends MemberContext {
    _op: Token;
    _entries: FieldInitializerListContext;
    constructor(parser: CELParser, ctx: MemberContext);
    member(): MemberContext;
    RBRACE(): TerminalNode;
    LBRACE(): TerminalNode;
    COMMA(): TerminalNode;
    fieldInitializerList(): FieldInitializerListContext;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class PrimaryContext extends ParserRuleContext {
    constructor(parser?: CELParser, parent?: ParserRuleContext, invokingState?: number);
    get ruleIndex(): number;
    copyFrom(ctx: PrimaryContext): void;
}
export declare class CreateListContext extends PrimaryContext {
    _op: Token;
    _elems: ExprListContext;
    constructor(parser: CELParser, ctx: PrimaryContext);
    RPRACKET(): TerminalNode;
    LBRACKET(): TerminalNode;
    COMMA(): TerminalNode;
    exprList(): ExprListContext;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class CreateStructContext extends PrimaryContext {
    _op: Token;
    _entries: MapInitializerListContext;
    constructor(parser: CELParser, ctx: PrimaryContext);
    RBRACE(): TerminalNode;
    LBRACE(): TerminalNode;
    COMMA(): TerminalNode;
    mapInitializerList(): MapInitializerListContext;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class ConstantLiteralContext extends PrimaryContext {
    constructor(parser: CELParser, ctx: PrimaryContext);
    literal(): LiteralContext;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class NestedContext extends PrimaryContext {
    _e: ExprContext;
    constructor(parser: CELParser, ctx: PrimaryContext);
    LPAREN(): TerminalNode;
    RPAREN(): TerminalNode;
    expr(): ExprContext;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class IdentOrGlobalCallContext extends PrimaryContext {
    _leadingDot: Token;
    _id: Token;
    _op: Token;
    _args: ExprListContext;
    constructor(parser: CELParser, ctx: PrimaryContext);
    IDENTIFIER(): TerminalNode;
    RPAREN(): TerminalNode;
    DOT(): TerminalNode;
    LPAREN(): TerminalNode;
    exprList(): ExprListContext;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class ExprListContext extends ParserRuleContext {
    _expr: ExprContext;
    _e: ExprContext[];
    constructor(parser?: CELParser, parent?: ParserRuleContext, invokingState?: number);
    expr_list(): ExprContext[];
    expr(i: number): ExprContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class FieldInitializerListContext extends ParserRuleContext {
    _IDENTIFIER: Token;
    _fields: Token[];
    _s21: Token;
    _cols: Token[];
    _expr: ExprContext;
    _values: ExprContext[];
    constructor(parser?: CELParser, parent?: ParserRuleContext, invokingState?: number);
    IDENTIFIER_list(): TerminalNode[];
    IDENTIFIER(i: number): TerminalNode;
    COLON_list(): TerminalNode[];
    COLON(i: number): TerminalNode;
    expr_list(): ExprContext[];
    expr(i: number): ExprContext;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class MapInitializerListContext extends ParserRuleContext {
    _expr: ExprContext;
    _keys: ExprContext[];
    _s21: Token;
    _cols: Token[];
    _values: ExprContext[];
    constructor(parser?: CELParser, parent?: ParserRuleContext, invokingState?: number);
    expr_list(): ExprContext[];
    expr(i: number): ExprContext;
    COLON_list(): TerminalNode[];
    COLON(i: number): TerminalNode;
    COMMA_list(): TerminalNode[];
    COMMA(i: number): TerminalNode;
    get ruleIndex(): number;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class LiteralContext extends ParserRuleContext {
    constructor(parser?: CELParser, parent?: ParserRuleContext, invokingState?: number);
    get ruleIndex(): number;
    copyFrom(ctx: LiteralContext): void;
}
export declare class BytesContext extends LiteralContext {
    _tok: Token;
    constructor(parser: CELParser, ctx: LiteralContext);
    BYTES(): TerminalNode;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class UintContext extends LiteralContext {
    _tok: Token;
    constructor(parser: CELParser, ctx: LiteralContext);
    NUM_UINT(): TerminalNode;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class NullContext extends LiteralContext {
    _tok: Token;
    constructor(parser: CELParser, ctx: LiteralContext);
    NULL(): TerminalNode;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class BoolFalseContext extends LiteralContext {
    _tok: Token;
    constructor(parser: CELParser, ctx: LiteralContext);
    FALSE(): TerminalNode;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class StringContext extends LiteralContext {
    _tok: Token;
    constructor(parser: CELParser, ctx: LiteralContext);
    STRING(): TerminalNode;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class DoubleContext extends LiteralContext {
    _sign: Token;
    _tok: Token;
    constructor(parser: CELParser, ctx: LiteralContext);
    NUM_FLOAT(): TerminalNode;
    MINUS(): TerminalNode;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class BoolTrueContext extends LiteralContext {
    _tok: Token;
    constructor(parser: CELParser, ctx: LiteralContext);
    TRUE(): TerminalNode;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
export declare class IntContext extends LiteralContext {
    _sign: Token;
    _tok: Token;
    constructor(parser: CELParser, ctx: LiteralContext);
    NUM_INT(): TerminalNode;
    MINUS(): TerminalNode;
    enterRule(listener: CELListener): void;
    exitRule(listener: CELListener): void;
    accept<Result>(visitor: CELVisitor<Result>): Result;
}
